@@ -20,6 +20,7 @@ namespace HandBrakeWPF.Services
     using HandBrake.Interop.Utilities;
 
     using HandBrakeWPF.Model;
+    using HandBrakeWPF.Model.Options;
     using HandBrakeWPF.Model.Video;
     using HandBrakeWPF.Properties;
     using HandBrakeWPF.Services.Interfaces;
@@ -279,7 +280,7 @@ namespace HandBrakeWPF.Services
             defaults.Add(UserSettingConstants.UpdateStatus, false);
             defaults.Add(UserSettingConstants.LastUpdateCheckDate, DateTime.Now.Date.AddDays(-30));
             defaults.Add(UserSettingConstants.DaysBetweenUpdateCheck, 1);
-            defaults.Add(UserSettingConstants.DarkThemeMode, DarkThemeMode.Light);
+            defaults.Add(UserSettingConstants.DarkThemeMode, DarkThemeMode.System);
             defaults.Add(UserSettingConstants.ShowPreviewOnSummaryTab, true);
             defaults.Add(UserSettingConstants.MainWindowMinimize, false);
             defaults.Add(UserSettingConstants.ClearCompletedFromQueue, false);
@@ -343,6 +344,7 @@ namespace HandBrakeWPF.Services
 
             defaults.Add(UserSettingConstants.ExcludedExtensions, new List<string> { "png", "jpg", "srt", "ass", "ssa", "txt" });
             defaults.Add(UserSettingConstants.RecursiveFolderScan, false);
+            defaults.Add(UserSettingConstants.DefaultRangeMode, DefaultRangeMode.Chapters);
             
             // Preview
             defaults.Add(UserSettingConstants.LastPreviewDuration, 30);
